package com.ynet.life.net.upload;

import com.ynet.gene.core.GENEConstance;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.mvc.upload.VerifyFileType;
import java.util.regex.Pattern;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_net_upload.jar:com/ynet/life/net/upload/UploadFileMvc.class */
public class UploadFileMvc {
    protected String id;
    protected long maxFileSize = -1;
    private Pattern fileTypePattern;
    public static final TranFailException EXCEPTION_FILE_TYPE = new TranFailException("EBLN0000", "文件上传类型有误");
    public static final TranFailException EXCEPTION_FILE_CONTENT = new TranFailException("EBLN0000", "上传文件类型与内容不一致");

    public void validateType(String fileName) throws TranFailException {
        if (this.fileTypePattern == null) {
            return;
        }
        String fileType = LifeFile.getFileType(fileName);
        if (!this.fileTypePattern.matcher(fileType).matches()) {
            Trace.logError(GENEConstance.GENE_MVC, EXCEPTION_FILE_TYPE.getShowMessage());
            throw EXCEPTION_FILE_TYPE;
        }
    }

    public void validateType(FileItem item) throws TranFailException {
        if (this.fileTypePattern == null) {
            return;
        }
        String name = item.getName();
        String fileName = name;
        if (StringUtils.isNotEmpty(name) && fileName.indexOf("\\") >= 0) {
            fileName = StringUtils.substringAfterLast(fileName, "\\");
        }
        String fileType = LifeFile.getFileType(fileName);
        if (!this.fileTypePattern.matcher(fileType).matches()) {
            Trace.logError(GENEConstance.GENE_MVC, EXCEPTION_FILE_TYPE.getShowMessage());
            throw EXCEPTION_FILE_TYPE;
        }
        if (!VerifyFileType.getFileType(item, fileType.toLowerCase())) {
            Trace.logError(GENEConstance.GENE_MVC, EXCEPTION_FILE_CONTENT.getShowMessage());
            throw EXCEPTION_FILE_CONTENT;
        }
    }

    public void setId(String id) {
        this.id = id;
    }

    public void setMaxFileSize(String maxFileSize) {
        this.maxFileSize = Long.parseLong(maxFileSize);
    }

    public void setFileType(String fileType) {
        try {
            this.fileTypePattern = Pattern.compile(fileType, 2);
        } catch (RuntimeException ex) {
            Trace.logError(GENEConstance.GENE_MVC, "文件类型正则表达式[" + fileType + "]格式有误", ex);
        }
    }
}
